FaceScannerOptions class

Class representing configurations of the DocumentScanner.

Constructors

FaceScannerOptions({bool useFrontCamera = false, FaceScannerCameraOptions cameraOptions = const FaceScannerCameraOptions(), Language language = Language.EN})
const

Properties

cameraOptions FaceScannerCameraOptions
final
hashCode int
The hash code for this object.
no setterinherited
language Language
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
useFrontCamera bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited